==> onecx-permissions-client-0.10.0-sources.jar: gen/org/tkit/onecx/permission/model/ApplicationsPermissions.java <==
package gen.org.tkit.onecx.permission.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import gen.org.tkit.onecx.permission.model.ApplicationPermissions;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import java.lang.reflect.Type;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
public class ApplicationsPermissions  {

    private List<ApplicationPermissions> applications;

    /**
    * Get applications
    * @return applications
    **/
    @JsonProperty("applications")
          @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public List<ApplicationPermissions> getApplications() {
        return applications;
    }

    /**
     * Set applications
     **/
    public void setApplications(List<ApplicationPermissions> applications) {
        this.applications = applications;
    }

    public ApplicationsPermissions applications(List<ApplicationPermissions> applications) {
        this.applications = applications;
        return this;
    }
    public ApplicationsPermissions addApplicationsItem(ApplicationPermissions applicationsItem) {
        if (this.applications == null){
            applications = new ArrayList<>();
        }
        this.applications.add(applicationsItem);
        return this;
    }

    /**
     * Create a string representation of this pojo.
     **/
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationsPermissions {\n");

        sb.append("    applications: ").append(toIndentedString(applications)).append("\n");
        
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private static String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
    public static class ApplicationsPermissionsQueryParam  {

        @jakarta.ws.rs.QueryParam("applications")
        private List<ApplicationPermissions> applications = null;

        /**
        * Get applications
        * @return applications
        **/
        @JsonProperty("applications")
        public List<ApplicationPermissions> getApplications() {
            return applications;
        }

        /**
         * Set applications
         **/
        public void setApplications(List<ApplicationPermissions> applications) {
            this.applications = applications;
        }

        public ApplicationsPermissionsQueryParam applications(List<ApplicationPermissions> applications) {
            this.applications = applications;
            return this;
        }
        public ApplicationsPermissionsQueryParam addApplicationsItem(ApplicationPermissions applicationsItem) {
            this.applications.add(applicationsItem);
            return this;
        }

        /**
         * Create a string representation of this pojo.
         **/
        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("class ApplicationsPermissionsQueryParam {\n");

            sb.append("    applications: ").append(toIndentedString(applications)).append("\n");
            sb.append("}");
            return sb.toString();
        }

        /**
         * Convert the given object to string with each line indented by 4 spaces
         * (except the first line).
         */
        private static String toIndentedString(Object o) {
            if (o == null) {
                return "null";
            }
            return o.toString().replace("\n", "\n    ");
        }
    }
}

==> onecx-permissions-client-0.19.0-sources.jar: gen/org/tkit/onecx/permission/model/ApplicationsPermissions.java <==
package gen.org.tkit.onecx.permission.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import gen.org.tkit.onecx.permission.model.ApplicationPermissions;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import java.lang.reflect.Type;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
public class ApplicationsPermissions  {

    private List<ApplicationPermissions> applications;

    /**
    * Get applications
    * @return applications
    **/
    @JsonProperty("applications")
          @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public List<ApplicationPermissions> getApplications() {
        return applications;
    }

    /**
     * Set applications
     **/
    public void setApplications(List<ApplicationPermissions> applications) {
        this.applications = applications;
    }

    public ApplicationsPermissions applications(List<ApplicationPermissions> applications) {
        this.applications = applications;
        return this;
    }
    public ApplicationsPermissions addApplicationsItem(ApplicationPermissions applicationsItem) {
        if (this.applications == null){
            applications = new ArrayList<>();
        }
        this.applications.add(applicationsItem);
        return this;
    }

    /**
     * Create a string representation of this pojo.
     **/
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ApplicationsPermissions {\n");

        sb.append("    applications: ").append(toIndentedString(applications)).append("\n");
        
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private static String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
    public static class ApplicationsPermissionsQueryParam  {

        @jakarta.ws.rs.QueryParam("applications")
        private List<ApplicationPermissions> applications = null;

        /**
        * Get applications
        * @return applications
        **/
        @JsonProperty("applications")
        public List<ApplicationPermissions> getApplications() {
            return applications;
        }

        /**
         * Set applications
         **/
        public void setApplications(List<ApplicationPermissions> applications) {
            this.applications = applications;
        }

        public ApplicationsPermissionsQueryParam applications(List<ApplicationPermissions> applications) {
            this.applications = applications;
            return this;
        }
        public ApplicationsPermissionsQueryParam addApplicationsItem(ApplicationPermissions applicationsItem) {
            this.applications.add(applicationsItem);
            return this;
        }

        /**
         * Create a string representation of this pojo.
         **/
        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("class ApplicationsPermissionsQueryParam {\n");

            sb.append("    applications: ").append(toIndentedString(applications)).append("\n");
            sb.append("}");
            return sb.toString();
        }

        /**
         * Convert the given object to string with each line indented by 4 spaces
         * (except the first line).
         */
        private static String toIndentedString(Object o) {
            if (o == null) {
                return "null";
            }
            return o.toString().replace("\n", "\n    ");
        }
    }
}
